@@ -13,7 +13,7 @@ import os
 import urllib
 
 DB_FORMAT = '%Y-%m-%d %H:%M:%S'
-FRAMEWORK_VERSION = '0.7'
+FRAMEWORK_VERSION = '0.8'
 HOME_PATH = os.path.expanduser("~")
 DB_PATH = HOME_PATH + '/.mPIM/mcalendar2.db'
 LAUNCH_UPDATE_DB_ONCE = False
@@ -66,7 +66,7 @@ class Database:
 #          self.cursor = self.db.cursor()
           self.cursor.execute('CREATE TABLE events (uuid TEXT PRIMARY KEY, start_datetime DATETIME, end_datetime DATETIME,title TEXT, description TEXT, repeat INTEGER, repeat_rule TEXT, repeat_exdate TEXT, last_update DATETIME, google_event_id TEXT, google_cal_id TEXT)')
           self.db.commit()
-          self.cursor.execute('CREATE TABLE attendees (event_uuid TEXT, who_id TEXT, name TEXT, statut INTEGER )')
+          self.cursor.execute('CREATE TABLE attendees (event_uuid TEXT, who_id TEXT, name TEXT, statut TEXT )')
           self.db.commit()
           self.cursor.execute('CREATE TABLE alarms (event_uuid TEXT, alarm_id INTEGER, alarm_datetime DATETIME, alarm_activated INTEGER, alarm_description TEXT)')
           self.db.commit()
@@ -95,6 +95,10 @@ class Database:
             self.cursor.execute('CREATE TABLE sync_logs (date DATETIME,text TEXT);')
             self.db.commit()
 
+          if v < '0.8':
+            self.cursor.execute('ALTER TABLE attendees MODIFY statut TEXT;')
+            self.db.commit()
+
         def close(self):
           self.db.close()
 
@@ -232,7 +236,7 @@ class Alarm:
             try:
               osso.alarmd.get_alarm(self.alarm_id).cancel_alarm()
             except:
-              pass
+              LogIt().append('Error on alarmd : '+str(e))
 
         def _activate(self):
 #          LogIt().append('Activate alarm at '+str())
@@ -241,7 +245,10 @@ class Alarm:
           print 'IS_MAEMO:'+str(IS_MAEMO)
           print 'datetime(local):'+str(self.alarm_datetime.astimezone(dateutil.tz.tzlocal()).utctimetuple())
           if (self.alarm_activated == 1) and (IS_MAEMO==True):
-            self.alarm_id = osso.alarmd.add_alarm(time.mktime(self.alarm_datetime.astimezone(dateutil.tz.tzlocal()).utctimetuple()),title=self.strip_accents(self.alarm_description))
+            try:
+              self.alarm_id = osso.alarmd.add_alarm(time.mktime(self.alarm_datetime.astimezone(dateutil.tz.tzlocal()).utctimetuple()),title=self.strip_accents(self.alarm_description))
+            except StandardError,e:
+              LogIt().append('Error on alarmd : '+str(e))
           db = Database(DB_PATH)
           db.cursor.execute('INSERT INTO alarms (alarm_id,alarm_datetime,event_uuid,alarm_activated,alarm_description) VALUES (?,?,?,?,?) ;', [str(self.alarm_id),self.alarm_datetime.strftime(DB_FORMAT),self.event_uuid,self.alarm_activated,self.alarm_description])
           db.db.commit()
@@ -295,6 +302,7 @@ class Event:
                 self.title = event[8]
               self.lastup = datetime.datetime.strptime(event[5],DB_FORMAT)
               self.lastup = self.lastup.replace(tzinfo=dateutil.tz.tzutc())
+#              LogIt().append('DEBUG:load_from_db().lastup:'+str(self.lastup))
               self.google_event_id = event[4]
               if event[7] != None:
                 self.google_cal_id = event[7]
@@ -310,12 +318,13 @@ class Event:
 
               db2.cursor.execute('SELECT who_id,name,statut FROM attendees WHERE event_uuid="'+suuid+'"')
               for attendee in db2.cursor.fetchall():
-                self.who.append(Attendee(attendee[0],attendee[1],int(attendee[2])==1))
+                if ('ACCEPTED' in attendee[2]) or ('TENTATIVE' in attendee[2]) or ('INVITED' in attendee[2]):
+                  self.who.append(Attendee(attendee[0],attendee[1],attendee[2]))
               db2.close()
             db.close()
 
         def add_attendee(self,name,email):
-          self.who.append(Attendee(email,name,True))
+          self.who.append(Attendee(email,name,'INVITED'))
 
         def get_interval(self):
           if self.repeat_rule != '':
@@ -405,6 +414,9 @@ class Event:
 
         def save_to_db(self):
             db = Database(DB_PATH)
+            self.lastup = datetime.datetime.now()
+            self.lastup = self.lastup.replace(tzinfo=dateutil.tz.tzlocal()).astimezone(dateutil.tz.tzutc())
+            
             if self.new==False:
               db.cursor.execute('DELETE FROM alarms where event_uuid = ?;',[self.uuid,])
               db.db.commit()
@@ -421,7 +433,7 @@ class Event:
               db.cursor.execute('DELETE FROM attendees where event_uuid = ?;',[self.uuid,])
               db.db.commit()
             for attendee in self.who:
-              db.cursor.execute('INSERT INTO attendees (event_uuid,who_id,name,statut) VALUES (?,?,?,?);',[self.uuid,attendee.email,attendee.name,str(int(attendee.statut))])
+              db.cursor.execute('INSERT INTO attendees (event_uuid,who_id,name,statut) VALUES (?,?,?,?);',[self.uuid,attendee.email,attendee.name,str(attendee.statut)])
               db.db.commit()
 
             if self.new==True:
