@@ -42,13 +42,15 @@ class mCalendar(object):
 
   __pretty_app_name__ = "mCalendar"
   __app_name__ = "mcalendar"
-  __version__ = "0.5.0"
+  __version__ = "0.5.3"
 
   _glade_files = [
+#    'ui/mcalendar.glade',
     '/usr/lib/mcalendar/ui/mcalendar.glade',
   ]
 
   def __init__(self):
+    import hildon
     self._callbackList = None
     global IS_MAEMO
     for path in mCalendar._glade_files:
@@ -75,19 +77,18 @@ class mCalendar(object):
       self._widgetTree.get_widget("ToHildonize").reparent(self._window)
       self._app.add_window(self._window)
 
-      self._journal_window = hildon.Window()
-      self._journal_window.hide()
-#      self._window.set_border_width(0)
-      self._widgetTree.get_widget("vbox7").reparent(self._journal_window)
-      self._app.add_window(self._journal_window)
+    self._window.show()
+    threading.Thread(target=self._launched).start()
 
+  def _launched(self):
+    global IS_MAEMO
+    gtk.gdk.threads_enter()    
+    if IS_MAEMO == True:
       hildon.hildon_helper_set_thumb_scrollbar(self._widgetTree.get_widget('ScrolledView'),True)
-      hildon.hildon_helper_set_thumb_scrollbar(self._widgetTree.get_widget('ScrolledDetails'),True)
+#      hildon.hildon_helper_set_thumb_scrollbar(self._widgetTree.get_widget('ScrolledDetails'),True)
       hildon.hildon_helper_set_thumb_scrollbar(self._widgetTree.get_widget('ScrolledJournal'),True)
       self._window.connect("key-press-event", self._on_key_press)
       self._window.connect("window-state-event", self._on_window_state_change)
-    else:
-      IS_MAEMO = False
 
     if IS_MAEMO == True:
       self._window.set_title("mCalendar")
@@ -139,7 +140,8 @@ class mCalendar(object):
       "on_bAdd_Attendee_clicked":self._eventeditor_attendee_new,
 
     }
-    self._widgetTree.signal_autoconnect(callbackMapping)
+    self._widgetTree.signal_autoconnect(callbackMapping) 
+    gtk.gdk.threads_leave()
 
     #load prefs
     self._prefs = mcalendar_prefs.mPrefs()
@@ -162,12 +164,12 @@ class mCalendar(object):
     self._current_view = self._prefs.get_int_value('default_current_view')    
     self._current_datetime = datetime.datetime.now()
 
+    gtk.gdk.threads_enter()
     if self._window:
       self._window.connect("delete-event", self._win_closebox)
-    if self._journal_window:
-      self._journal_window.connect("delete-event", self._journal_window_closebox)
     threading.Thread(target=self._idle_setup).start()
     self.timer = gobject.timeout_add(5000, self._update_sync_progress)
+    gtk.gdk.threads_leave()
 
   def _cancel(self,widget):
     if self._current_virtual_win == 1:
@@ -247,7 +249,7 @@ class mCalendar(object):
       self._widgetTree.get_widget("AddButton").hide()
       self._widgetTree.get_widget("BackButton").show()
       self._widgetTree.get_widget("ValidateButton").show()
-      self._widgetTree.get_widget("InfoButton").show()
+      self._widgetTree.get_widget("InfoButton").hide()
       self._widgetTree.get_widget("SearchButton").hide()
       self._widgetTree.get_widget("TodayButton").hide()
       self._widgetTree.get_widget("WeekButton").hide()
@@ -600,7 +602,10 @@ class mCalendar(object):
     self._children_color_bg(self._widgetTree.get_widget("Toolbutton"),'#E2E2E2')
     self._children_color_bg(self._widgetTree.get_widget("Toolbutton2"),'#E2E2E2')
     self._children_color_bg(self._widgetTree.get_widget("VirtualView"),'#E9E9E9')
-    self._children_color_bg(self._widgetTree.get_widget("VirtualEdit"),'#E9E9E9')
+    self._children_color_bg(self._widgetTree.get_widget("page1_bg"),'#F0F0F0')
+    self._children_color_bg(self._widgetTree.get_widget("page2_bg"),'#E9E9E9')
+    self._children_color_bg(self._widgetTree.get_widget("page3_bg"),'#E9E9E9')
+    self._children_color_bg(self._widgetTree.get_widget("page4_bg"),'#E9E9E9')
     self._children_color_bg(self._widgetTree.get_widget("VirtualPicker"),'#E9E9E9')
     self._children_color_bg(self._widgetTree.get_widget("VirtualLogs"),'#E9E9E9')
     for toolbuttons in self._widgetTree.get_widget("Toolbutton").get_children():
@@ -706,7 +711,7 @@ class mCalendar(object):
 #    self._eventeditor_bSetRecurrence = self._widgetTree.get_widget("bSetRecurrence")
 #   self._eventeditor_bSetAlarm = self._widgetTree.get_widget("bSetAlarm")
     self._eventeditor_tDescription = self._widgetTree.get_widget("edit_description")
-    self._eventeditor_bTitle = self._widgetTree.get_widget("edit_title")
+#    self._eventeditor_bTitle = self._widgetTree.get_widget("edit_title")
     gtk.gdk.threads_leave()
 #
     #Recurrency Editor Widget
@@ -750,6 +755,18 @@ class mCalendar(object):
     self.attendeesListTree.append_column(column_id)
     gtk.gdk.threads_leave()
 
+    if IS_MAEMO == True:
+      gtk.gdk.threads_enter()
+      self._journal_window = hildon.Window()
+      self._journal_window.hide()
+#      self._window.set_border_width(0)
+      self._widgetTree.get_widget("vbox7").reparent(self._journal_window)
+      self._app.add_window(self._journal_window)
+      gtk.gdk.threads_leave()
+
+    if self._journal_window:
+      self._journal_window.connect("delete-event", self._journal_window_closebox)
+
     return False
 
   def _init_list(self,a_model,a_list,type_store=0):
@@ -1041,16 +1058,16 @@ class mCalendar(object):
 
   def _eventeditor_show_more(self,widget):
     if self._eventeditor_more == True:
-      self._widgetTree.get_widget("frame_calendar").hide()
-      self._widgetTree.get_widget("frame_attendees").hide()
-      self._widgetTree.get_widget("frame_reminder").hide()
-      self._widgetTree.get_widget("frame_reccurency").hide()
+#      self._widgetTree.get_widget("frame_calendar").hide()
+#      self._widgetTree.get_widget("frame_attendees").hide()
+#      self._widgetTree.get_widget("frame_reminder").hide()
+#      self._widgetTree.get_widget("frame_reccurency").hide()
       self._eventeditor_more = False
     else:
-      self._widgetTree.get_widget("frame_calendar").show()
-      self._widgetTree.get_widget("frame_attendees").show()
-      self._widgetTree.get_widget("frame_reminder").show()
-      self._widgetTree.get_widget("frame_reccurency").show()
+#      self._widgetTree.get_widget("frame_calendar").show()
+#      self._widgetTree.get_widget("frame_attendees").show()
+#      self._widgetTree.get_widget("frame_reminder").show()
+#      self._widgetTree.get_widget("frame_reccurency").show()
       self._eventeditor_more = True
 
   def _open_event(self,uuid,default_start=None,default_end=None):
@@ -1065,14 +1082,14 @@ class mCalendar(object):
     else:
       event = mcalendar_framework.Event(uuid)
     self._eventeditor_event = event
-    self._widgetTree.get_widget("frame_calendar").hide()
-    self._widgetTree.get_widget("frame_attendees").hide()
-    self._widgetTree.get_widget("frame_reminder").hide()
-    self._widgetTree.get_widget("frame_reccurency").hide()
+#    self._widgetTree.get_widget("frame_calendar").hide()
+#    self._widgetTree.get_widget("frame_attendees").hide()
+#    self._widgetTree.get_widget("frame_reminder").hide()
+#    self._widgetTree.get_widget("frame_reccurency").hide()
     self._eventeditor_more = False
     self._eventeditor_edit_start_datetime.set_text( mcalendar_framework.convert_for_display(event.start_datetime,'%a %x %X'))
     self._eventeditor_edit_end_datetime.set_text(mcalendar_framework.convert_for_display(event.end_datetime,'%a %x %X'))
-    self._eventeditor_bTitle.set_text(event.title)
+#    self._eventeditor_bTitle.set_text()
     print 'event title:'+event.title
     self._eventeditor_tDescription.get_buffer().set_text(event.description)   
 
@@ -1110,6 +1127,10 @@ class mCalendar(object):
         self._eventeditor_edit_frequency.set_active(2)
       if frequency==0:
         self._eventeditor_edit_frequency.set_active(3)
+        
+    #Attendee  and alarm Load
+    self._eventeditor_load_attendees()
+    self._eventeditor_load_alarm()
 
     self._update_virtual(1)
 
@@ -1159,29 +1180,30 @@ class mCalendar(object):
     # self._recurrenceeditor_load()
     # self._update_virtual(3)
 
-  # def _eventeditor_set_alarm(self,widget):
-    # self._alarmsList.clear()
-    # for alarm in self._eventeditor_event.alarms:
-      # print alarm.alarm_datetime 
-      # if type(alarm.alarm_datetime)== datetime.datetime:
-        # self._alarmsList.append((alarm.alarm_id,alarm.alarm_datetime.strftime('%a %x %X')))
+  def _eventeditor_load_alarm(self):
+    self._alarmsList.clear()
+    for alarm in self._eventeditor_event.alarms:
+      #print alarm.alarm_datetime 
+      if type(alarm.alarm_datetime)== datetime.datetime:
+        self._alarmsList.append((alarm.alarm_id,alarm.alarm_datetime.strftime('%a %x %X')))
     # self._update_virtual(4)
 
-  # def _eventeditor_set_attendee(self,widget):
-    # self._attendeesList.clear()
-    # for attendee in self._eventeditor_event.who:
-      # self._attendeesList.append((attendee.email,attendee.name))
-    # self._update_virtual(5)
+  def _eventeditor_load_attendees(self):
+    self._attendeesList.clear()
+    for attendee in self._eventeditor_event.who:
+      self._attendeesList.append((attendee.email,attendee.name))
+    #self._update_virtual(5)
 
   def _eventeditor_cancel(self,widget):
     self._update_virtual(0)
 
   def _eventeditor_validate(self,widget):
     #base
-    self._eventeditor_event.title = self._eventeditor_bTitle.get_text()
+#    self._eventeditor_event.title = self._eventeditor_bTitle.get_text()
     start,end = self._eventeditor_tDescription.get_buffer().get_bounds()
-    self._eventeditor_event.description = self._eventeditor_tDescription.get_buffer().get_text(start,end)
-
+    text = self._eventeditor_tDescription.get_buffer().get_text(start,end)
+    self._eventeditor_event.title = text.split('\n')[0]
+    self._eventeditor_event.description = text
     #attendee
     self._eventeditor_event.clear_attendees()
     iter = self._attendeesList.get_iter_root()
@@ -1285,8 +1307,8 @@ class mCalendar(object):
     self._widgetTree.get_widget("picker_calendar").select_day(self._current_datetime.day)
     self._datetimepicker_selector = 'alarm'
     self._update_virtual(2)
-    self._widgetTree.get_widget("frame_attendees").hide()
-    self._widgetTree.get_widget("frame_attendees").show()
+#    self._widgetTree.get_widget("frame_attendees").hide()
+#    self._widgetTree.get_widget("frame_attendees").show()
 
   def _eventeditor_alarm_delete(self,widget):
     if ask_dialogue(self._window,'Do you really want to delete this event ?')==True:
